==> kports-0.6.0.tar.bz2: kports-0.6.0/src/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2005, 2006 by Hannes Hauswedell                         *
 *   hannes.hauswedell@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "kports.h"
#include <kapplication.h>
#include <dcopclient.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <qsplashscreen.h>
#include <kmessagebox.h>
#include <qstring.h>
#include <pwd.h>


static const char description[] =
    I18N_NOOP("A KDE Frontend to the FreeBSD Ports System");

static const char version[] = "0.6.0";

static KCmdLineOptions options[] =
{
    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
    KCmdLineLastOption
};
/*
int changeUser()
{
	QString username = getlogin();//(std::getenv("LOGNAME"));
	uint user_id  = getpwnam(username.latin1())->pw_uid;
	
	std::cout << "LOGIN USER'S ID: "<< user_id<< std::endl;
	 
	seteuid(user_id);

}*/

int main(int argc, char **argv)
{
	
	
	 
	KAboutData about("kports", I18N_NOOP("KPorts"), version, description,
	KAboutData::License_GPL, "(C) 2005, 2006 Hannes Hauswedell", 0, 0, "xytral at users dot sf dot net");
	about.addAuthor( "Hannes Hauswedell", 0, "hannes dot hauswedell at gmail dot com" );
	KCmdLineArgs::init(argc, argv, &about);
	KCmdLineArgs::addCmdLineOptions(options);
	KApplication app;
		
	  
	if (getuid() != 0)
		if (KMessageBox::warningContinueCancel(0, i18n("KPorts is not running with Root-Previliges."
				" You will be asked whenever a Process needs them, but you will not be able to abort these Processes."
				" Please run \"kdesu kports\" in future."), QString(), 
				KStdGuiItem::cont(), "dontWarnNotRoot")
			!= KMessageBox::Continue)
			return 0;
			
			
	// register ourselves as a dcop client
	app.dcopClient()->registerAs(app.name(), false);
	
	// see if we are starting with session management
	if (app.isRestored())
	{
		RESTORE(KPorts);
	}
	else
	{
		// no session.. just start up normally
	//      KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
	//      if (args->count() == 0)
	//      {
			QPixmap pic("/usr/local/share/apps/kports/kports-splash.jpg");
			if (pic.isNull())
			{
				KPorts *widget = new KPorts;
				widget->show();
			} else
			{
				QSplashScreen *splash = new QSplashScreen(pic);
				splash->show();
				KPorts *widget = new KPorts;
				widget->show();
				splash->finish(widget);
			}
	/*        }
		else
		{
		int i = 0;
		for (; i < args->count(); i++)
		{
			KPorts *widget = new KPorts;
			widget->show();
	//                widget->load(args->url(i));
		}
		}
		args->clear();*/
	}

		
	return app.exec();
}

==> kports-0.6.1.tar.bz2: kports-0.6.1/src/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2005, 2006 by Hannes Hauswedell                         *
 *   hannes.hauswedell@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "kports.h"
#include <kapplication.h>
#include <dcopclient.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <qsplashscreen.h>
#include <kmessagebox.h>
#include <qstring.h>
#include <pwd.h>


static const char description[] =
    I18N_NOOP("A KDE Frontend to the FreeBSD Ports System");

static const char version[] = "0.6.1";

static KCmdLineOptions options[] =
{
    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
    KCmdLineLastOption
};
/*
int changeUser()
{
	QString username = getlogin();//(std::getenv("LOGNAME"));
	uint user_id  = getpwnam(username.latin1())->pw_uid;
	
	std::cout << "LOGIN USER'S ID: "<< user_id<< std::endl;
	 
	seteuid(user_id);

}*/

int main(int argc, char **argv)
{
	
	
	 
	KAboutData about("kports", I18N_NOOP("KPorts"), version, description,
	KAboutData::License_GPL, "(C) 2005, 2006 Hannes Hauswedell", 0, 0, "xytral at users dot sf dot net");
	about.addAuthor( "Hannes Hauswedell", 0, "hannes dot hauswedell plus kports at gmail dot com" );
	KCmdLineArgs::init(argc, argv, &about);
	KCmdLineArgs::addCmdLineOptions(options);
	KApplication app;
		
	  
	if (getuid() != 0)
		if (KMessageBox::warningContinueCancel(0, i18n("KPorts is not running with Root-Previliges."
				" You will be asked whenever a Process needs them, but you will not be able to abort these Processes."
				" Please run \"kdesu kports\" in future."), QString(), 
				KStdGuiItem::cont(), "dontWarnNotRoot")
			!= KMessageBox::Continue)
			return 0;
			
			
	// register ourselves as a dcop client
	app.dcopClient()->registerAs(app.name(), false);
	
	// see if we are starting with session management
	if (app.isRestored())
	{
		RESTORE(KPorts);
	}
	else
	{
		// no session.. just start up normally
	//      KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
	//      if (args->count() == 0)
	//      {
			QPixmap pic("/usr/local/share/apps/kports/kports-splash.jpg");
			if (pic.isNull())
			{
				KPorts *widget = new KPorts;
				widget->show();
			} else
			{
				QSplashScreen *splash = new QSplashScreen(pic);
				splash->show();
				KPorts *widget = new KPorts;
				widget->show();
				splash->finish(widget);
			}
	/*        }
		else
		{
		int i = 0;
		for (; i < args->count(); i++)
		{
			KPorts *widget = new KPorts;
			widget->show();
	//                widget->load(args->url(i));
		}
		}
		args->clear();*/
	}

		
	return app.exec();
}
